function filteredCorr = f_FilterCorr( x, y, w )
% Filtered Sliding Window Correlation
%
% Title: Filtered Correlation and Allowed Frequency Spectra in Dynamic 
%        Functional Connectivity
% Journal of Neuroscience Methods
% JNEUMETH-D-20-00071
% History: Major Revision R1
%
	nX = length(x);
	nFilterWeights = length(w);
	nFilteredTR = nX - nFilterWeights +1;

	filteredCorr = zeros(1,nFilteredTR);
	for kk=1:nFilteredTR
		samplesUsed = kk:1:kk+nFilterWeights-1;
	
		xx = x(samplesUsed) - mean(x(samplesUsed));
		yy = y(samplesUsed) - mean(y(samplesUsed));
		
		xy = w*(xx.*yy)';
		x2 = abs(w)*(xx.^2)';
		y2 = abs(w)*(yy.^2)';
	
		filteredCorr(kk) = sqrt(2)*xy./sqrt(x2*y2);
	end

end

