%
%
% Title: Filtered Correlation and Allowed Frequency Spectra in Dynamic 
%        Functional Connectivity
% Journal of Neuroscience Methods
% JNEUMETH-D-20-00071
%
% Figure 4 and Figure 5
%
% Coded by : Victor M. Vergara, PhD
%			 2020-June- 9: Submitted Revision R1
%			 2020-June-29: Minor change mostly comments
%
%
%
clear;clc;close all;
fprintf(['\nFiltered Correlation and \nAllowed Frequency',	...
         ' Spectra in \nDynamic Functional Connectivity\n']);
fprintf('\nJournal of Neuroscience Methods\n');
fprintf('\n\nVictor M. Vergara and Vince D. Calhoun\n');
fprintf('\n\nFigure4: Repeat simulations of Figure 3, but using FSWC\n'); 
fprintf('\n\nFigure5: Isolate the highest dyn. connectivity frequency\n'); 
fprintf(['\n\tSimulation of phase between\n\t', ...
		'simulated time varying signals x(t) and  y(t)\n\n'])
fprintf('\tx(t) and y(t) are sum of cosines temporal signals\n');
fprintf('\t\tx(t) = sum ( cos( w_i * t + angle1_i )\n');
fprintf('\t\ty(t) = sum ( cos( w_i * t + angle2_i + phase(t) )\n');
fprintf(['\tphase(t) is also time varying with several \n', ...
		 '\tfrequencies wp and phase-dephasings anglep\n']);
fprintf('\t\typhase(t) = sum ( cos( wp_i * t + anglep_i) )\n\n\n');

%% CONFIGURATION: Set the dynamic functional connectivity
%
% Uncomment the different configurations to simulate the different
% sub-figures a, b, c and d. By default Figure 3a is uncommented.
%
% Figure4a
fprintf('Simulating Figure 4a\n\n');
lowestFreq  = 0.02	; % time course lowest  time course frequency in Hz
highestFreq = 0.10	; % time course highest time course frequency in Hz
dFC_Frequencies = [0.01 0.005];% phase(x,y)(t) frequencies in Hz
dFC_Amplitudes = [0.4 0.4];    % phase(x,y)(t) amplitudes
dFC_Phases = [0 pi/5];         % phase(x,y)(t) dephasings in rads
nFilterTaps = 100;             % phase(x,y)(t) filter size in TR
cutoffFrquency = 0.02;         % phase(x,y)(t) low pass cut off freq

% Figure4b
% fprintf('Simulating Figure 4b\n\n');
% lowestFreq  = 0.02 ; % time course lowest  time course frequency in Hz
% highestFreq = 0.10 ; % time course highest time course frequency in Hz
% dFC_Frequencies = [0.01 0.1];% phase(x,y)(t) frequencies in Hz
% dFC_Amplitudes = [0.4 0.4];  % phase(x,y)(t) amplitudes
% dFC_Phases = [0 pi/5 2*pi/5];% phase(x,y)(t) dephasings in rads 
% nFilterTaps = 100;           % phase(x,y)(t) filter size in TR
% cutoffFrquency = 0.02;       % phase(x,y)(t) low pass cut off freq

%Figure 4c
% fprintf('Simulating Figure 4c\n\n');
% lowestFreq  = 0.02 ; % time course lowest  time course frequency in Hz
% highestFreq = 0.10 ; % time course highest time course frequency in Hz
% dFC_Frequencies = [0.01 0.1];% phase(x,y)(t) frequencies in Hz
% dFC_Amplitudes = [0.4 0.4];  % phase(x,y)(t) amplitudes
% dFC_Phases = [0 pi/5];       % phase(x,y)(t) dephasings in rads
% nFilterTaps = 100;           % phase(x,y)(t) filter size in TR
% cutoffFrquency = 0.12;       % phase(x,y)(t) low pass cut off freq

%Figure 4d
% fprintf('Simulating Figure 4d\n\n');
% lowestFreq  = 0.07 ; % time course lowest  time course frequency in Hz
% highestFreq = 0.10 ; % time course highest time course frequency in Hz
% dFC_Frequencies = [0.01 0.1];% phase(x,y)(t) frequencies in Hz
% dFC_Amplitudes = [0.4 0.4];  % phase(x,y)(t) amplitudes
% dFC_Phases = [0 pi/5];       % phase(x,y)(t) dephasings in rads
% nFilterTaps = 100;           % phase(x,y)(t) filter size in TR
% cutoffFrquency = 0.12;       % phase(x,y)(t) low pass cut off freq

% Figure 5
% fprintf('Simulating Figure 5\n\n');
% lowestFreq  = 0.08;	% in Hz
% highestFreq = 0.12 ;	% in Hz
% dFC_Frequencies = [0.01 0.10]; % in Hz
% dFC_Amplitudes = [0.4 0.4];
% dFC_Phases = [0 pi/5 ]; 
% NFiltstep = 100;
% cutoffFrquency = [0.08 0.12];



%% CONFIGURATION: Setup the simulation 
% Configuring variables
FontSz = 22; % Just the font size for figures
axisFontSz = 14; % Just the font size for figure axes
TR =  2;% [sec] simulated MRI TR
timeL = 600;% [sec] time length of the simulation
nIter = 100;	% number of iterations

% variables calculated from configuration
nTR = ceil(timeL/TR);	% How many TR to simulate
t = TR*(0:nTR-1);	% time variable in seconds
Fstep = 1/(TR*nTR); % frequency step
% Fstep = 0.01;
F  = lowestFreq:Fstep:highestFreq; % simulated cosine frequency in Hz
nF = length(F);	% Number of Frequencies
A = sqrt(2/nF)*ones(1,nF); % makes x and y have var = 1

%% ESTIMATE Dynamic Connectivity dc(x,y)(t) to Simulated 
dFC = zeros(length(dFC_Frequencies),length(t));
for kk = 1:length(dFC_Frequencies)
	dFC(kk,:) = dFC_Amplitudes(kk)*cos(2*pi*dFC_Frequencies(kk)*t + ...
		dFC_Phases(kk));
end
CC = mean(dFC); % Simulated Ground Truth dc(x,y)(t) = sum of cosines  


%% Configuration: Set the FIR filter for the FSWC
nFilterWeights = 100;
af=1;
bf=fir1(nFilterWeights,2*cutoffFrquency*TR); % bf = FSWC filter taps
nFilteredTR = nTR - nFilterWeights; % Filtered data have less time points
%% Simulate
FXY = zeros(nIter,nTR);
FfilterXY = zeros(nIter, nTR);
corrPlot = 0;
fprintf('Estimating mean frequency spectrum from %d iterations\n',nIter);
fprintf('\titeration number     ');
for ii=1:nIter
	x = zeros(1,nTR);
	y =	zeros(1,nTR);
	for f=1:nF	% Add each frequency
		PP = 2*pi*rand(1,1);
		w = 2*pi*F(f);	% Frequency in rads/sec
		x = x + A(f)*cos(w*t + PP );
		y = y + A(f)*cos(w*t + PP + acos(CC) );
	end
	XY = x.*y;
	%% Calculate the FIlter ( X times Y )
	filteredCorr = f_FilterCorr( x, y, bf );

	%% Add the spectrums
	FXY(ii,:) =  abs(fft(XY)).^2;
	FfilterXY(ii,:)= abs(fft(	...
		[filteredCorr,zeros(1,nFilterWeights)] ...
		)).^2; 
	
	%% This section selects one of the iterations to plot the time courses
	% just find the correlation without the problem of filter settling time
% 	plot(CC(floor(nFilterTaps/2) + (1:nTR-nFilterTaps))');
% 	hold on;plot( filteredCorr(1:nTR-nFilterTaps));hold off;
	ccp = abs(corr(CC(floor(nFilterTaps/2) + ...
	      (1:nTR-nFilterTaps))',filteredCorr(1:nTR-nFilterTaps)'));
	% keep the max correlation results
	% corrPlot is the correlation between Ground Truth and the selected
	% XY(t) to plot
	if ccp > corrPlot
		XYp =XY;
		filteredCorrp = filteredCorr;
		corrPlot = ccp;
	end
	
	fprintf('\b\b\b\b%04.0f',ii);
end
fprintf('\n\tsimulation finished\n')


%% plot the three signals x y and ground truth
figure('Position',[64 64 1152 256]);
%% plot 1 Time courses
subplot(1,3,1);
plot(t(1:nFilteredTR) + (TR*nFilterWeights/2), ...
	CC((1:nFilteredTR) + floor(nFilterWeights/2)));
set(gca,'FontSize',axisFontSz);
xlabel('Time sec','FontSize',FontSz);
ylabel('\theta_(_t_)','FontSize',FontSz);
% legend('Ground Truth','Filtered Corr');
AX= axis();
AX(1:2) = [150 350];
axis(AX);

%% Filtered Plot
subplot(1,3,2);
plot(t(1:nFilteredTR) + (TR*nFilterWeights/2),filteredCorrp,'k');

xlabel('Time sec','FontSize',FontSz);
ylabel('Filtered Correlation','FontSize',FontSz);
set(gca,'FontSize',axisFontSz);
axis(AX);
%% Frequency PLot
subplot(1,3,3);
fXY = (0:1:(nTR-1))/(nTR*TR);

maxfreqq = 0.25; % in the plot
frqXY = 1:1:ceil(maxfreqq*nTR*TR);

%estimate the frequency of the filter
filX = [bf,zeros(1,nTR - length(bf))];
filF = fft(filX);

% normalize freq spectrum
A= mean(FXY); 
B= mean(FfilterXY);
C = 0.99*abs(filF).^2;
% 
A = A./max(A);
B = B./max(B);
plot(fXY(frqXY),(A(frqXY)),'k',	...
	 fXY(frqXY),(B(frqXY)),'r--',	...
	 fXY(frqXY),(C(frqXY)),'b.-'	...
	 );
legend('XY','Filtered Corr','FIR Low Pass')
xlabel('Frequency Hz','FontSize',FontSz);
ylabel('PSD','FontSize',FontSz);
axis([0 maxfreqq 0 1]);
set(gca,'FontSize',axisFontSz);

%% display the correlation between ground truth and FNC
fprintf('\n\nCorrelation GroundTruth vs. Filtered[XY] = %f\n\ndone\n', ...
	corrPlot);

