function figure6_SWC_separate_phase_noise()
%
%
% Title: Filtered Correlation and Allowed Frequency Spectra in Dynamic 
%        Functional Connectivity
% Journal of Neuroscience Methods
% JNEUMETH-D-20-00071
% History: Major Revision R1
%
% Figure 6
%
% Coded by : Victor M. Vergara, PhD
% 2020-June-9 : requires SPM installed
%
%

%% HUMAN : Long TR Load input fMRI data
datapath = './time_courses/';
TR = 2.0; % TR for this data in seconds
v = spm_vol([datapath,'gica_sub001_timecourses_ica_s1_adult.nii']);
tc = spm_read_vols(v); %% tc has the time courses
xaxisrange = 0.25;

%% HUMAN : Small TR Load input fMRI data
% datapath = './time_courses/';
% TR = 0.46; % TR for this data in seconds
% v = spm_vol([datapath,'gica_sub007_timecourses_ica_s1_pediatric.nii']);
% tc = spm_read_vols(v); %% tc has the time courses
% xaxisrange = 0.35;

%% Setup Window Length WL
secWL = 50;
WL = floor(secWL/TR);
w = ones(WL,1)./WL;

%% Setup bandwidths to use
% BW = [0.2 0.7; 0.275 0.40; 0.250 0.40; 0.225 0.40];
% BW = [0.15 0.30; 0.125 0.30; 0.1 0.30; 0.075 0.30];
BW = [0.1 0.15; 0.075 0.15; 0.05 0.15; 0.025 0.15];
% BW = [0.08 0.125; 0.06 0.125; 0.04 0.125; 0.02 0.125];
% BW = [0.08 0.1; 0.06 0.1; 0.04 0.1; 0.02 0.1];
% we are making subplots and these must coincide with the nuber of BW
% configured
n_subplot_col = 4; 
n_subplot_row = 1;
n_subplots = size(BW,1);
figure('Position',[64 64 1400 256]);
for subp = 1:n_subplots
	%% For each subplot a different BW is filtered
	Wn = BW(subp,:) .*(2*TR) ;
	[b,a] = butter(5,Wn); % uncomment if used
	tf = filter(b,a,tc);

	%% assess the phase by simple multiplication x*y
	xy = getxy(tf);
	
	%% assess the phase by simple multiplication x*y
	swc = getSWC(tf,WL);
	%% Extract the mean time courses
	subplot(n_subplot_row,n_subplot_col,subp);
	f_PlotFreqPowerSpectrum([swc;zeros(1000,size(swc,2))],TR,1,1);
	hold on;
	f_PlotFreqPowerSpectrum([xy;zeros(1000,size(xy,2))],TR,1,1);
	f_PlotFreqPowerSpectrum([w;zeros(1000,1)],TR,1,1);
	hold off;
	axis tight
	title(['Bandwidth [',num2str(BW(subp,1)),' - ',num2str(BW(subp,2)),']'])
 	legend('SWC Spectrum','Complete Spectrum','Weigths Spectrum');
	set(gca, 'YScale', 'linear');
 	ax = axis();ax(2) = xaxisrange;axis(ax);	
	
end

end

function [swc,mid] = getSWC(tc,wl)
	nTC  = size(tc,1);
	nIC  = size(tc,2);
	nDFC = nIC*(nIC-1)/2;
%% perform SWC
nSWC = nTC - wl + 1;
swc = zeros(nSWC,nDFC);

mid = zeros(nDFC,2);
for kk=1:nSWC
	ii = 0;
	for rr = 1:nIC-1
		for cc = rr+1:nIC;
			ii = ii + 1;
			mid(ii,:) = [rr,cc];
			
			x = tc(  kk+(1:wl)-1   ,rr);
			y = tc(  kk+(1:wl)-1   ,cc);
			swc(kk,ii) = corr(	x ,  y  );
							
		end
	end
end

end



function xy = getxy(tc)
	nIC  = size(tc,2);
	nDFC = nIC*(nIC-1)/2;
	xy = zeros(size(tc,1),nDFC);
	ii = 0;
	for rr = 1:nIC-1
		for cc = rr+1:nIC;
			ii = ii + 1;
			X = tc(:,rr); % time course rr
			Y = tc(:,cc); % time course cc
			X = X - mean(X); % demean
			Y = Y - mean(Y); % demean
			xy(:,ii) = X.*Y;
		end
	end
end

